TuningFork.Gm.Fonts (TuningFork v0.1.11)

Copy Markdown View Source

The soundfont files Strudel plays each gm_* name from, in the order n picks them.

Summary

Functions

The file n picks for name, wrapping round the list; nil for a name that has none.

The font files for name, or nil for a name that has none.

Functions

file(name, n)

@spec file(String.t(), integer()) :: String.t() | nil

The file n picks for name, wrapping round the list; nil for a name that has none.

files(name)

@spec files(String.t()) :: [String.t()] | nil

The font files for name, or nil for a name that has none.