TuningFork.Gm.Names (TuningFork v0.1.11)

Copy Markdown View Source

Strudel's gm_* instrument names and the General MIDI programs they stand for.

Summary

Functions

Every name, sorted.

The program number name stands for, or nil for a name that is not one.

Functions

names()

@spec names() :: [String.t()]

Every name, sorted.

program(name)

@spec program(String.t()) :: 0..127 | nil

The program number name stands for, or nil for a name that is not one.