TuningFork.Sink.Collect (TuningFork v0.1.11)

Copy Markdown View Source

A sink that sends everything written to a process as {:pcm, binary}.

Summary

Functions

Open the sink.

Send pcm to the owner, then sleep for as long as the audio it holds lasts.

Functions

open(opts)

Open the sink.

Options

  • :owner — who receives {:pcm, binary}, default the opening process
  • :rate — samples per second, default 44100
  • :channels — samples per frame, default 2

write(map, pcm)

Send pcm to the owner, then sleep for as long as the audio it holds lasts.