A sounding note or an open effect, for TuningFork.SonicPi.control/2.
Summary
Types
@type t() :: %TuningFork.SonicPi.Handle{kind: :note | :fx, ref: reference()}
A sounding note or an open effect, for TuningFork.SonicPi.control/2.
@type t() :: %TuningFork.SonicPi.Handle{kind: :note | :fx, ref: reference()}