The soundfont files Strudel plays each gm_* name from, in the order n picks them.
Summary
Functions
The file n picks for name, wrapping round the list; nil for a name that has none.
The font files for name, or nil for a name that has none.