A sink that sends everything written to a process as {:pcm, binary}.
{:pcm, binary}
Open the sink.
Send pcm to the owner, then sleep for as long as the audio it holds lasts.
pcm
:owner
:rate
:channels