Sonic Pi's effects as the TuningFork.Fx effects that play them.
iex> TuningFork.SonicPi.Effects.to_fx(:lpf, cutoff: 69)
[lowpass: [hz: 440.0]]
Summary
Functions
Whether name is an effect here.
Every effect name, sorted.
The TuningFork.Fx effects name with opts stands for, as a keyword list.
Functions
Whether name is an effect here.
@spec names() :: [atom()]
Every effect name, sorted.
The TuningFork.Fx effects name with opts stands for, as a keyword list.
Usually one entry; :krush is two. Raises ArgumentError for a name that is not here.